/**
 * @file mqtt_publish.ino
 * @author René Bohne
 * @brief Tests if the GEENYmodem can establish a network connection, connects to the tingg.io mqtt broker, and published data
 * @date 2021-02-26
 * 
 * @copyright Copyright (c) 2021 René Bohne
 * 
 */
#include <Wire.h>
#include <GEENYmodem.h>

GEENYmodem modem = GEENYmodem();

void setup(void)
{
  Serial.begin(115200);
  Serial1.begin(115200);

  while (!Serial)
    delay(10);
  Serial.println("GEENYmodem test!");

  // Try to initialize!
  if (!modem.begin(Serial1, Serial))
  {
    Serial.println("Failed to find GEENYmodem");
    while (1)
    {
      delay(10);
    }
  }
  Serial.println("GEENYmodem Found!");

  String mi = modem.getModemInfo();
  Serial.print("Modem Info: ");
  Serial.println(mi);

  Serial.println("connecting to GPRS network...");
  boolean network_connected = modem.connectGPRS();
  if (network_connected)
  {
    Serial.println("GPRS network connection successful");
    Serial.print("operator: ");
    Serial.println(modem.getOperator());

    Serial.print("IP: ");
    Serial.println(modem.getLocalIP());
  }
  else
  {
    Serial.println("GPRS network connection failed");
    while (1)
    {
      delay(10);
    }
  }

  modem.powerup();

  Serial.println("connecting to tingg.io ...");
  boolean connected = modem.connectMQTT();
  if (connected)
  {
    Serial.println("mqtt connection successful");
  }
  else
  {
    Serial.println("mqtt connection failed");
    while (1)
    {
      delay(10);
    }
  }
}

int counter = 0;
char mqtt_buffer[30];
void loop()
{
  //clear buffer
  memset(&mqtt_buffer[0], 0, sizeof(mqtt_buffer));

  sprintf_P(mqtt_buffer, PSTR("{'counter':'%d'}"), counter++);
  Serial.println(mqtt_buffer);
  modem.mqttPublish("message_pub", mqtt_buffer);
  delay(50000);
}